@@ -50,7 +50,8 @@ def _get_columns(item):
     columns = list(item.keys())
     if 'tenant_id' in columns:
         columns.remove('tenant_id')
-        columns.append('project_id')
+        if 'project_id' not in columns:
+            columns.append('project_id')
     binding_columns = [
         'binding:host_id',
         'binding:profile',
@@ -128,6 +129,8 @@ def _get_attrs(client_manager, parsed_args):
     if parsed_args.host:
         attrs['binding:host_id'] = parsed_args.host
 
+    if parsed_args.dns_name is not None:
+        attrs['dns_name'] = parsed_args.dns_name
     # It is possible that name is not updated during 'port set'
     if parsed_args.name is not None:
         attrs['name'] = str(parsed_args.name)
@@ -148,6 +151,12 @@ def _get_attrs(client_manager, parsed_args):
         ).id
         attrs['tenant_id'] = project_id
 
+    if parsed_args.disable_port_security:
+        attrs['port_security_enabled'] = False
+
+    if parsed_args.enable_port_security:
+        attrs['port_security_enabled'] = True
+
     return attrs
 
 
@@ -227,6 +236,12 @@ def _add_updatable_args(parser):
         metavar='<host-id>',
         help=argparse.SUPPRESS,
     )
+    parser.add_argument(
+        '--dns-name',
+        metavar='dns-name',
+        help=_("Set DNS name to this port "
+               "(requires DNS integration extension)")
+    )
 
 
 class CreatePort(command.ShowOne):
@@ -304,6 +319,17 @@ class CreatePort(command.ShowOne):
             action='store_true',
             help=_("Associate no security groups with this port")
         )
+        port_security = parser.add_mutually_exclusive_group()
+        port_security.add_argument(
+            '--enable-port-security',
+            action='store_true',
+            help=_("Enable port security for this port (Default)")
+        )
+        port_security.add_argument(
+            '--disable-port-security',
+            action='store_true',
+            help=_("Disable port security for this port")
+        )
 
         return parser
 
@@ -526,6 +552,17 @@ class SetPort(command.Command):
             action='store_true',
             help=_("Clear existing security groups associated with this port")
         )
+        port_security = parser.add_mutually_exclusive_group()
+        port_security.add_argument(
+            '--enable-port-security',
+            action='store_true',
+            help=_("Enable port security for this port")
+        )
+        port_security.add_argument(
+            '--disable-port-security',
+            action='store_true',
+            help=_("Disable port security for this port")
+        )
 
         return parser
 
